==> haskell-data-dword-0.3.1.2-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-dword
version: 0.3.1.2
id: data-dword-0.3.1.2-3VimIP7Kqe02FhIqdRkzuM
key: data-dword-0.3.1.2-3VimIP7Kqe02FhIqdRkzuM
license: BSD-3-Clause
copyright: 2011-2018 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-dword
synopsis: Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.
category: Data
abi: 5cee09619911903b8a4fb77dddd6bf64
exposed: True
exposed-modules:
    Data.DoubleWord Data.DoubleWord.TH
hidden-modules: Data.DoubleWord.Base
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-dword-0.3.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-dword-0.3.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-dword-0.3.1.2
hs-libraries: HSdata-dword-0.3.1.2-3VimIP7Kqe02FhIqdRkzuM
depends:
    base-4.12.0.0 data-bword-0.1.0.1-BIS2AZE89UaKR3N10Px6Og
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html: /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-dword-0.3.1.2-35-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-data-dword.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: data-dword
version: 0.3.1.2
id: data-dword-0.3.1.2-IecX8ZMFNUI96BJXkkV54h
key: data-dword-0.3.1.2-IecX8ZMFNUI96BJXkkV54h
license: BSD-3-Clause
copyright: 2011-2018 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/data-dword
synopsis: Stick two binary words together to get a bigger one
description:
    This package provides Template Haskell utilities for declaring fixed-length
    binary word data types. Signed and unsigned 96, 128, 160, 192, 224, and
    256-bit types are predefined.
category: Data
abi: 7b0f4a70f3fb56dc99300a27c65f7951
exposed: True
exposed-modules:
    Data.DoubleWord Data.DoubleWord.TH
hidden-modules: Data.DoubleWord.Base
import-dirs: /usr/lib/ghc-8.6.5/site-local/data-dword-0.3.1.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/data-dword-0.3.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/data-dword-0.3.1.2
hs-libraries: HSdata-dword-0.3.1.2-IecX8ZMFNUI96BJXkkV54h
depends:
    base-4.12.0.0 data-bword-0.1.0.1-BIS2AZE89UaKR3N10Px6Og
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    template-haskell-2.14.0.0
haddock-interfaces: /usr/share/doc/haskell-data-dword/html/data-dword.haddock
haddock-html: /usr/share/doc/haskell-data-dword/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
